@@ -1,13 +1,15 @@
 
+import importlib.metadata
+
+__version__ = importlib.metadata.version("cuta")
+version = __version__
+
 from . import api
 from . import core
 
 from .api import from_env
 
 
-__version__ = "0.1.0"
-version = __version__
-
 __all__ = ["api", "from_env", "core"]
 
 
