@@ -267,6 +267,9 @@ class App:
 
         Build application
         """
+        build_path = self.root.joinpath(".cuta", "build")
+        build_path.mkdir(exist_ok=True)
+
         source = "app.py"
         target = "../.cuta/build/function.zip"
 
